@@ -1,9 +1,7 @@
-from .handler import XLPowerQueryHandler
 from .classes import PQManager, ExcelQueryService, PQFileStore, DependencyResolver, PowerQueryMetadata, PowerQueryScript
 from .ui import PQManagerUI
 
 __all__ = [
-    "XLPowerQueryHandler",
     "ExcelQueryService",
     "PQFileStore",
     "DependencyResolver",
